.. _api_writers:

=======
Writers
=======

Classes to write AltamISA model files to ISA-Tab investigation, study and assay files.
Note that writers can issue warnings, see :ref:`api_Writers` on how to capture them properly.

.. contents::

altamisa.isatab.InvestigationWriter
-----------------------------------

.. autoclass:: altamisa.isatab.InvestigationWriter
    :members:

altamisa.isatab.AssayWriter
---------------------------

.. autoclass:: altamisa.isatab.AssayWriter
    :members:

altamisa.isatab.StudyWriter
---------------------------

.. autoclass:: altamisa.isatab.StudyWriter
    :members:
